# Changelog

## 3.4.0 (2025-07-31)

Full Changelog: [v0.0.1-alpha.0...v3.4.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v0.0.1-alpha.0...v3.4.0)

### Features

* **api:** update via SDK Studio ([ce75dcc](https://github.com/WorqHat/worqhat-python-sdk/commit/ce75dcc31b078bab025560c5b196a4eecf7f1227))
* **api:** update via SDK Studio ([ec19825](https://github.com/WorqHat/worqhat-python-sdk/commit/ec19825709fbe7994a811981d5eb77630a0594ce))
* **api:** update via SDK Studio ([85ab7a2](https://github.com/WorqHat/worqhat-python-sdk/commit/85ab7a2e5c871ed5921ef6044c0f9926b939948d))
* **api:** update via SDK Studio ([1dca18a](https://github.com/WorqHat/worqhat-python-sdk/commit/1dca18acf452a7cc35c6e541d69b8a31ac90d29a))
* **api:** update via SDK Studio ([fbb6ab5](https://github.com/WorqHat/worqhat-python-sdk/commit/fbb6ab5d66c30d8ee3bd9328eab85304efd42614))


### Chores

* configure new SDK language ([c4d0258](https://github.com/WorqHat/worqhat-python-sdk/commit/c4d0258ea522088e0f6181228d1f04a64230b2d7))
* sync repo ([b2b1c38](https://github.com/WorqHat/worqhat-python-sdk/commit/b2b1c381aa08870a807c303164f6ff9689f8aea2))
* sync repo ([4766968](https://github.com/WorqHat/worqhat-python-sdk/commit/476696875aa8f142f588c4f016fa8110a0ec4e08))
* update SDK settings ([8d58885](https://github.com/WorqHat/worqhat-python-sdk/commit/8d5888563b3042cb684d9a4406a09edd2be22889))
* update SDK settings ([a1ff3c3](https://github.com/WorqHat/worqhat-python-sdk/commit/a1ff3c388307c293932c8ef069ae9ad3a03c393c))
* update SDK settings ([53e95ac](https://github.com/WorqHat/worqhat-python-sdk/commit/53e95acd14d9d4dd063c1c71a1ed0bcd9ab86e69))
* update SDK settings ([f5a73c5](https://github.com/WorqHat/worqhat-python-sdk/commit/f5a73c54db1e7d7d865701c79b13034a08ef5341))
* update SDK settings ([9ff0620](https://github.com/WorqHat/worqhat-python-sdk/commit/9ff062000f153819b5629a262395551a723b2382))
* update SDK settings ([d605766](https://github.com/WorqHat/worqhat-python-sdk/commit/d605766da0d10451b716cbf715c96e6b4ccf90b9))
* update SDK settings ([29497ca](https://github.com/WorqHat/worqhat-python-sdk/commit/29497ca3d7fc8232a9b0cc0fb70cb963c4624b33))
* update SDK settings ([e386fb8](https://github.com/WorqHat/worqhat-python-sdk/commit/e386fb86761c1ef06bd99b5a85b2fd6710d17737))
* update SDK settings ([0dbf509](https://github.com/WorqHat/worqhat-python-sdk/commit/0dbf5097e700966f2546ea967d0669eae280dbb9))
* update SDK settings ([64384f2](https://github.com/WorqHat/worqhat-python-sdk/commit/64384f2c7f05b7a54d89881791857068c10f1250))
* update SDK settings ([6c05440](https://github.com/WorqHat/worqhat-python-sdk/commit/6c05440a6f753841abdac7153f9bc0cb7688f7d9))
